@@ -72,7 +72,7 @@ class CollectionListModel : public KDescendantsProxyModel
 = checked status is equivalent to whether it is selected or not.
 = An alarm type is specified, whereby Collections which are enabled for that
 = alarm type are checked; Collections which do not contain that alarm type, or
-= which are disabled for that alarm type, are unchedked.
+= which are disabled for that alarm type, are unchecked.
 =============================================================================*/
 class CollectionCheckListModel : public KCheckableProxyModel
 {
@@ -196,6 +196,8 @@ class CollectionControlModel : public Akonadi::FavoriteCollectionsModel
          *  with the current KAlarm calendar format.
          *  Optionally, the enabled status can be ignored.
          *
+         *  @param collection The collection
+         *  @param type    The alarm type
          *  @param format  If the reply is false, and the calendar is not read-only
          *                 but its backend calendar storage format is not the
          *                 current KAlarm format, @p format is set to the calendar
@@ -208,14 +210,15 @@ class CollectionControlModel : public Akonadi::FavoriteCollectionsModel
          *         -1 = read-only (if @p format == KACalendar::Current), or
          *              disabled or incompatible format.
          */
-        static int isWritableEnabled(const Akonadi::Collection&, CalEvent::Type, KACalendar::Compat& format);
+        static int isWritableEnabled(const Akonadi::Collection& collection, CalEvent::Type type, KACalendar::Compat& format);
 
         /** Return the standard collection for a specified mime type.
+         *  @param type       The mime type
          *  @param useDefault false to return the defined standard collection, if any;
          *                    true to return the standard or only collection for the type.
          *  Reply = invalid collection if there is no standard collection.
          */
-        static Akonadi::Collection getStandard(CalEvent::Type, bool useDefault = false);
+        static Akonadi::Collection getStandard(CalEvent::Type type, bool useDefault = false);
 
         /** Return whether a collection is the standard collection for a specified
          *  mime type. */
@@ -248,11 +251,13 @@ class CollectionControlModel : public Akonadi::FavoriteCollectionsModel
         /** Find the collection to be used to store an event of a given type.
          *  This will be the standard collection for the type, but if this is not valid,
          *  the user will be prompted to select a collection.
-         *  @param noPrompt  don't prompt the user even if the standard collection is not valid
-         *  @param cancelled If non-null: set to true if the user cancelled
-         *             the prompt dialogue; set to false if any other error.
+         *  @param type         The event type
+         *  @param promptParent The parent widget for the prompt
+         *  @param noPrompt     Don't prompt the user even if the standard collection is not valid
+         *  @param cancelled    If non-null: set to true if the user cancelled the
+         *                      prompt dialogue; set to false if any other error
          */
-        static Akonadi::Collection destination(CalEvent::Type, QWidget* promptparent = nullptr, bool noPrompt = false, bool* cancelled = nullptr);
+        static Akonadi::Collection destination(CalEvent::Type type, QWidget* promptParent = nullptr, bool noPrompt = false, bool* cancelled = nullptr);
 
         /** Return the enabled collections which contain a specified mime type.
          *  If 'writable' is true, only writable collections are included.
